==> onnx2tf-1.0.43.tar.gz: onnx2tf-1.0.43/onnx2tf/ops/SequenceInsert.py <==
import random
random.seed(0)
import numpy as np
np.random.seed(0)
import tensorflow as tf
import onnx_graphsurgeon as gs
from onnx2tf.utils.common_functions import (
    get_constant_or_variable,
    print_node_info,
    inverted_operation_enable_disable,
    make_tf_node_info,
)


@print_node_info
@inverted_operation_enable_disable
def make_node(
    *,
    graph_node: gs.Node,
    tf_layers_dict: dict,
    **kwargs: dict,
):
    """SequenceInsert

    Parameters
    ----------
    graph_node: gs.Node
        graph_surgeon Node

    tf_layers_dict: dict
        optype, shape, dtype, tensorflow graph
    """
    before_op_output_shape_trans_1 = \
        tf_layers_dict.get(graph_node.inputs[0].name, {}).get('before_op_output_shape_trans', True)
    before_op_output_shape_trans_2 = \
        tf_layers_dict.get(graph_node.inputs[1].name, {}).get('before_op_output_shape_trans', True)
    before_op_output_shape_trans = \
        before_op_output_shape_trans_1 \
        and before_op_output_shape_trans_2

    graph_node_input_1 = get_constant_or_variable(
        graph_node.inputs[0],
        before_op_output_shape_trans,
    )
    graph_node_input_2 = get_constant_or_variable(
        graph_node.inputs[1],
        before_op_output_shape_trans,
    )
    graph_node_input_3 = None
    if len(graph_node.inputs) >= 3:
        graph_node_input_3 = get_constant_or_variable(
            graph_node.inputs[2],
            before_op_output_shape_trans,
        )
    graph_node_output: gs.Variable = graph_node.outputs[0]
    shape = graph_node_output.shape
    dtype = graph_node_output.dtype

    # Preserving Graph Structure (Dict)
    tf_layers_dict[graph_node_output.name] = {
        'optype': graph_node.op,
        'shape': shape,
        'dtype': dtype,
    }

    # Generation of TF OP
    input_sequence = tf_layers_dict[graph_node_input_1.name]['tf_node'] \
        if isinstance(graph_node_input_1, gs.Variable) else graph_node_input_1
    input_sequence_length = input_sequence.shape[-1]
    input_tensor = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
        if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
    position = tf_layers_dict[graph_node_input_3.name]['tf_node'] \
        if isinstance(graph_node_input_3, gs.Variable) else graph_node_input_3
    if position is None:
        position = input_sequence_length

    input_tensor = tf.expand_dims(input_tensor, 0)
    output_seq = None
    if input_sequence.shape[0] is not None:
        if input_sequence.shape[0] == 0:
            output_seq = tf.RaggedTensor.from_tensor(input_tensor)
        else:
            s1 = input_sequence[:position]
            s2 = input_sequence[position:]
            output_seq = tf.concat([s1, input_tensor, s2], axis=0)
    else:
        output_seq = tf.cond(
            tf.equal(
                x=input_sequence.bounding_shape(axis=0),
                y=0,
            ),
            lambda: tf.RaggedTensor.from_tensor(input_tensor),
            lambda: tf.concat(
                [
                    input_sequence[:position],
                    input_tensor,
                    input_sequence[position:],
                ],
                axis=0
            )
        )
    tf_layers_dict[graph_node_output.name]['tf_node'] = output_seq

    # Generation of Debug Info
    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
        make_tf_node_info(
            node_info={
                'tf_op_type': 'SequenceInsert',
                'tf_inputs': {
                    'input_sequence': input_sequence,
                    'input_tensor': input_tensor,
                    'position': position,
                },
                'tf_outputs': {
                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
                },
            }
        )

==> onnx2tf-1.7.13.tar.gz: onnx2tf-1.7.13/onnx2tf/ops/SequenceInsert.py <==
import random
random.seed(0)
import numpy as np
np.random.seed(0)
import tensorflow as tf
import onnx_graphsurgeon as gs
from onnx2tf.utils.common_functions import (
    get_constant_or_variable,
    print_node_info,
    inverted_operation_enable_disable,
    make_tf_node_info,
    get_replacement_parameter,
    pre_process_transpose,
    post_process_transpose,
)


@print_node_info
@inverted_operation_enable_disable
@get_replacement_parameter
def make_node(
    *,
    graph_node: gs.Node,
    tf_layers_dict: dict,
    **kwargs: dict,
):
    """SequenceInsert

    Parameters
    ----------
    graph_node: gs.Node
        graph_surgeon Node

    tf_layers_dict: dict
        optype, shape, dtype, tensorflow graph
    """
    before_op_output_shape_trans_1 = \
        tf_layers_dict.get(graph_node.inputs[0].name, {}).get('before_op_output_shape_trans', True)
    before_op_output_shape_trans_2 = \
        tf_layers_dict.get(graph_node.inputs[1].name, {}).get('before_op_output_shape_trans', True)
    before_op_output_shape_trans = \
        before_op_output_shape_trans_1 \
        and before_op_output_shape_trans_2

    graph_node_input_1 = get_constant_or_variable(
        graph_node.inputs[0],
        before_op_output_shape_trans,
    )
    graph_node_input_2 = get_constant_or_variable(
        graph_node.inputs[1],
        before_op_output_shape_trans,
    )
    graph_node_input_3 = None
    if len(graph_node.inputs) >= 3:
        graph_node_input_3 = get_constant_or_variable(
            graph_node.inputs[2],
            before_op_output_shape_trans,
        )
    graph_node_output: gs.Variable = graph_node.outputs[0]
    shape = graph_node_output.shape
    dtype = graph_node_output.dtype

    # Preserving Graph Structure (Dict)
    tf_layers_dict[graph_node_output.name] = {
        'optype': graph_node.op,
        'shape': shape,
        'dtype': dtype,
    }

    # Generation of TF OP
    input_sequence = tf_layers_dict[graph_node_input_1.name]['tf_node'] \
        if isinstance(graph_node_input_1, gs.Variable) else graph_node_input_1
    input_sequence_length = input_sequence.shape[-1]
    input_tensor = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
        if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
    position = tf_layers_dict[graph_node_input_3.name]['tf_node'] \
        if isinstance(graph_node_input_3, gs.Variable) else graph_node_input_3
    if position is None:
        position = input_sequence_length

    # Pre-process transpose
    input_sequence = pre_process_transpose(
        value_before_transpose=input_sequence,
        param_target='inputs',
        param_name=graph_node.inputs[0].name,
        **kwargs,
    )
    input_tensor = pre_process_transpose(
        value_before_transpose=input_tensor,
        param_target='inputs',
        param_name=graph_node.inputs[1].name,
        **kwargs,
    )
    position = pre_process_transpose(
        value_before_transpose=position,
        param_target='inputs',
        param_name=graph_node.inputs[2].name,
        **kwargs,
    )

    input_tensor = tf.expand_dims(input_tensor, 0)
    output_seq = None
    if input_sequence.shape[0] is not None:
        if input_sequence.shape[0] == 0:
            output_seq = tf.RaggedTensor.from_tensor(input_tensor)
        else:
            s1 = input_sequence[:position]
            s2 = input_sequence[position:]
            output_seq = tf.concat([s1, input_tensor, s2], axis=0)
    else:
        output_seq = tf.cond(
            tf.equal(
                x=input_sequence.bounding_shape(axis=0),
                y=0,
            ),
            lambda: tf.RaggedTensor.from_tensor(input_tensor),
            lambda: tf.concat(
                [
                    input_sequence[:position],
                    input_tensor,
                    input_sequence[position:],
                ],
                axis=0
            )
        )
    tf_layers_dict[graph_node_output.name]['tf_node'] = output_seq

    # Post-process transpose
    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
        param_target='outputs',
        param_name=graph_node.outputs[0].name,
        **kwargs,
    )

    # Generation of Debug Info
    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
        make_tf_node_info(
            node_info={
                'tf_op_type': 'SequenceInsert',
                'tf_inputs': {
                    'input_sequence': input_sequence,
                    'input_tensor': input_tensor,
                    'position': position,
                },
                'tf_outputs': {
                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
                },
            }
        )
